Struct Cfgr
#[repr(transparent)]pub struct Cfgr(pub u32);Expand description
ADC configuration register.
Tuple Fields
0: u32Implementations
impl Cfgr
impl Cfgr
pub const fn set_extsel(&mut self, val: u8)
pub const fn set_extsel(&mut self, val: u8)
External trigger selection for regular group.
pub const fn exten(&self) -> Exten
pub const fn exten(&self) -> Exten
External trigger enable and polarity selection for regular channels.
pub const fn set_exten(&mut self, val: Exten)
pub const fn set_exten(&mut self, val: Exten)
External trigger enable and polarity selection for regular channels.
pub const fn set_ovrmod(&mut self, val: bool)
pub const fn set_ovrmod(&mut self, val: bool)
Overrun mode.
pub const fn set_cont(&mut self, val: bool)
pub const fn set_cont(&mut self, val: bool)
Single / continuous conversion mode for regular conversions.
pub const fn set_autdly(&mut self, val: bool)
pub const fn set_autdly(&mut self, val: bool)
Delayed conversion mode.
pub const fn set_discen(&mut self, val: bool)
pub const fn set_discen(&mut self, val: bool)
Discontinuous mode for regular channels.
pub const fn set_discnum(&mut self, val: u8)
pub const fn set_discnum(&mut self, val: u8)
Discontinuous mode channel count.
pub const fn set_jdiscen(&mut self, val: bool)
pub const fn set_jdiscen(&mut self, val: bool)
Discontinuous mode on injected channels.
pub const fn set_awd1sgl(&mut self, val: bool)
pub const fn set_awd1sgl(&mut self, val: bool)
Enable the watchdog 1 on a single channel or on all channels.
pub const fn set_awd1en(&mut self, val: bool)
pub const fn set_awd1en(&mut self, val: bool)
Analog watchdog 1 enable on regular channels.
pub const fn set_jawd1en(&mut self, val: bool)
pub const fn set_jawd1en(&mut self, val: bool)
Analog watchdog 1 enable on injected channels.
pub const fn set_awd1ch(&mut self, val: u8)
pub const fn set_awd1ch(&mut self, val: u8)
Analog watchdog 1 channel selection.